/*
For making tables here is the code. You can put it in an ado file, or just stick the code, as is, in the top of the do-file
 
the syntax is
 
maketable_t using OUTPUTTABLE.out, rhs(RHS) varcol(VARCOL)
 
you run this after a regression, like you would run outreg
'rhs' is the name of the variable in the regression you want to put in the table
'varcol' is the name of the column where you want the output to go
 
so this works well if, say, you have a bunch of different outcome variables, each of which goes in a different row, and then a bunch of different countries/samples/etc, each of which goes in a different column.
 
so i think with a little work you can make your table using this command, although i think you'd have to transpose it so that the different outcome variables were in different rows and the different countries were in the columns.
 
-Ben 

*/

capture program drop maketable_t
program define maketable_t
 
local maxrows = 500
 
syntax using/, rhs(string) varcol(string) [replace] [append]
 
/*inputs:
 1 = dep variable name
 2 = indep variable name
 3 = variable number (this is the nth variable in the table)*/
 
local lhs = "`rhs'"
local newb = r(mean)   /*_b[`rhs']*/
local newse = r(p50)   /*_se[`rhs']*/
//qui test `rhs' = 0
local newp = r(sd)     /* r(p) */
 
if "`replace'" != "replace" & "`append'" != "append" {
 display "Must specify either replace or append"
 exit 
}
 
/*initialize dataset*/
preserve
clear
if "`replace'" == "replace" {
 qui set obs `maxrows'
 qui g col0 = ""
 qui g col1 = "`varcol'" in 1
 local whichcol = "col1"
}
else {
 capture insheet using `using'.out, names
 if _rc != 0 {
  display "File not found"
  exit
 }
 local whichcol = ""
 local howmanycols = 0
 foreach X of var col* {
  qui count if `X' == "`varcol'"
  if r(N) > 0 {
   local whichcol = "`X'" 
  }
  local howmanycols = `howmanycols' + 1
 }
  
 if "`whichcol'" == "" {
  /*make a new column*/
  qui g col`howmanycols' = "`varcol'" in 1
  local whichcol = "col`howmanycols'"
  }     
 
 
}
 
 
 
/*find which row to use*/
local lastrow = 0
local brow = 0
foreach X of num 1/`maxrows' {
 qui count if col0 == "`rhs'" in `X'
 if r(N) == 1 & `brow' == 0 {
  local brow = `X' 
 }
 qui count if col0 != "" in `X'
 if r(N) == 1 {
  local lastrow = `X' 
 } 
}
if `brow' == 0 {
 local brow = `lastrow' + 3
 
}
 

local browse = `brow' + 1
local bb = `brow' + 2 
qui replace col0 = "`rhs'" in `brow'
qui replace `whichcol' = string(`newb',"%4.3f") in `brow'
qui replace `whichcol' = "" + string(`newse',"%4.3f") + "" in `browse'
qui replace `whichcol' = "" + string(`newp',"%4.3f") + "" in  `bb'
/* 
qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.10
qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.05
qui replace `whichcol' = `whichcol' + "*" in `brow' if `newp' <= 0.01
*/ 
 
outsheet using `using'.out, replace
 
restore
end
