version 10.1
clear
set more off
set mem 700m

cd\
cd\IT

do "DoFiles Public\0. AdoFiles\multparse.ado"
do "DoFiles Public\0. AdoFiles\fanreg.ado"
do "DoFiles Public\0. AdoFiles\maketable.ado"


cd\
cd "IT\DoFiles Public\1. Expenditure"
*Does:  Generates contribution, household composition and size, worker, location, and urban/rural variables for each household
*Input:  All input files can be found in each country's respective directory within "OData", "OData\NI" for Nicaragua for example
*Output:  Results\`cty'_Exp.dta (and ID07_Tax.dta), "AL_Exp.dta" for example
	do "NG04_Exp 110129.do"
	do "DoFiles Public\1. Expenditure\PH_Exp 110129.do"  
	do "DoFiles Public\1. Expenditure\V02_Exp 110129.do" 
	do "DoFiles Public\1. Expenditure\ID07_Exp 110430.do"
	do "DoFiles Public\1. Expenditure\GU_Exp 110129.do"
	***Any time AL_Exp is rerun, AL Tax must be rerun afterward as well b/c it adds direct taxes to the hh_exp variable to have it in the desired form  
	do "DoFiles Public\1. Expenditure\AL_Exp 110129.do"
	***Any time ET_Exp is rerun, ET Tax must be rerun afterward  
	do "DoFiles Public\1. Expenditure\ET_Exp 110129.do"  
	do "DoFiles Public\1. Expenditure\PA_Exp 110129.do"  
	do "DoFiles Public\1. Expenditure\ZA_Exp 110129.do" 
	do "DoFiles Public\1. Expenditure\NI_Exp 110129.do"

cd\
cd "IT\DoFiles Public\2. Taxation" 
*Does:  Generates direct, indirect, and total tax paid by household variables (for ID07, this is built in with _Exp.dta)
*Input:  All input files can be found in each country's respective directory within "OData", "OData\NI" for Nicaragua for example
*Output:  Results\`cty'_Tax.dta, "V98_Tax.dta" for example
	do "PH Tax 110129.do"
	****Do NOT rerun ET Tax without first rerunning ET_Exp  
	do "DoFiles Public\2. Taxation\ET Tax 110129.do"  
	***Do NOT rerun AL Tax without first rerunning AL_Exp, else incorrectly high values of hh_exp will occur 
	do "DoFiles Public\2. Taxation\AL Tax 110129.do"
	do "DoFiles Public\2. Taxation\V02 Tax 110129.do" 


cd\
cd "IT\DoFiles Public\3. Wage Prediction"
*(Important only for countries on which have info for intensive margin)
*Does:  Prepare individual data which will be used for the calculation of an estimation of wage of each individual
*Input:  All input files can be found in each country's respective directory within "OData", "OData\NI" for Nicaragua for example
*Output:  Results\`cty'_ind_data.dta, "ZA_ind_data.dta" for example
	do "wage predictor ingredients 110129.do"

*Does:  Construct a prediction for wage of individuals, based on his/her characteristics collected/calculated by "wage predictor ingredients" do file; also determine average and minimum for each household
*Input:  Results\`country_abbreviation'_ind_data.dta, "ID07_ind_data.dta" for example; Results\`country_abbreviation'_Exp.dta, "AL_Exp.dta" for example
*Output:  Results\`cty'_ind_wage_predicted.dta, "AL_ind_wage_predicted.dta" for example
	do "DoFiles Public\3. Wage Prediction\wage predictor regression 110129.do"

cd\
cd "IT\DoFiles Public\4. Figures"
*Does:   Generates Figure 1
*Input:  Results\`cty'_Tax.dta, `cty'_Exp.dta
*Output: Results\Figure1_combined.gph
	do "Figure 1 110129.do"

cd\
cd "IT\DoFiles Public\5. Tables 
*Does:   Generates Tables 1 through 10
*Input:  Results\`cty'_Tax.dta, `cty'_Exp.dta, `cty'_ind_wage_predicted.dta, `cty'_ind_data.dta, OData\ID07\budget2007.dta, pds2008_a.dta, various files in OData\ID07\Data3 directory 
*Output: Various files of form table`w'--.out where `w' == 1-10
	do "Keep List 110129.do"
	do "DoFiles Public\5. Tables\Table 1 110129.do"
	do "DoFiles Public\5. Tables\Table 2 110129.do"
	do "DoFiles Public\5. Tables\Table 3 110129.do"
	do "DoFiles Public\5. Tables\Table 4&5 110201.do"
	do "DoFiles Public\5. Tables\Table 6&8 110409.do"
	do "DoFiles Public\5. Tables\Table 7 110409.do"
	do "DoFiles Public\5. Tables\Table 9 110409.do"
	do "DoFiles Public\5. Tables\Table 10 110430.do"

