*****/*Important:  Must rerun AL Exp before rerunning this file or will have incorrectly high expenditure variable values
																			See bottom about addition made to the hh_expenditure variable generated in AL_Exp*/

/*
This do file calculates the amount of formal taxes paid by hh:
	hid 				: hh identification code
	tot_tax   	: total amount of tax paid
	tot_dir 		: total amount of direct tax paid
	tot_ind 		: total amount of indirect tax paid
	alcohol_tax : total tax paid on alcohol
	tobacco_tax : total tax paid on tocacco
	fuel_tax  	: total tax paid on fuel
	vat_tax			: total vat paid
*/

/*All values in Old Leks 
  All are converted to per year*/


clear
set memo 50m
cd\
cd\IT
cd "OData\AL\Data\"

// defining rates of taxation
gl alc_rate  = 0.5
gl tob_rate  = 0.6
gl fuel_rate = 0.8             
gl vat_rate  = 0.2             

*********************************************************************************************************************Direct taxes **
******************************************************Taxes and insurance monthly average for non-farm business **
use 	non_farm_business_cl, replace

ren 	hhid hid
// converting to the annual base
g   	nonfarm_dir_tax    =  m05_q24c * 12                                                 

// collapsing to household level (some have more than single business)
collapse (sum) nonfarm_dir_tax,by(hid)			     
keep 	hid nonfarm_dir_tax

sort 		 hid
tempfile 	 direct01
save 		`direct01'

*******************************************************Taxes reported in non food expenditure in 12 M **
use non_food_expendituresC_cl, replace

ren  hhid hid

//choosing itm 44: other taxes(vehicle, radio, TV, etc) from the expenditure table of page 64
keep              if m12c_q00  == 44
g    other_dir_tax    =  m12c_q03    			

/*missing are not recognizable from zeros*/                                                
keep hid other_dir_tax

sort 		hid
tempfile 	direct02
save 		`direct02'
********************************************************************************************************************* Consumption taxes **
**********************************************************Tobacco & Alcohol 30Days**
use 	non_food_expendituresA_cl, replace
ren 		 hhid   hid

//keeping m12a_q02==1, because for other questions amount of expenditure has not been asked
keep  	 if  m12a_q02==1

keep  	 hid m12a_q00 m12a_q03

//keeping relevant info: item 12 is alcohol consumption and 13 is tobacco consumption
keep 		 if  m12a_q00 == 12 | m12a_q00  == 13

// reshaping to single line per household
reshape wide m12a_q03,i(hid) j(m12a_q00)

/*
If the expenditure is y, then                y  = (1+t)*x
thus the amount of tax paid is equal to      tx = t/(1+t)*y 
*/

// calculating yearly alcohol and tobacco taxes
g   alcohol_tax = m12a_q0313 * 12  * ($alc_rate/(1+$alc_rate)) 
g   tobacco_tax = m12a_q0312 * 12  * ($tob_rate/(1+$tob_rate))  

keep hid alcohol_t tobacco_t 
sort hid
tempfile tob_alc
save    `tob_alc'

************************************************************************************************************************Fuel**
   
use   totcons05.dta
ren   hhid       hid

/*Comes from the "totcons.do" from LSMS website, just sub4 is deducted as it's alcohol+tobacco consumption, to avoid double counting*/
egen  nfood_base = rsum(              sub1-sub3  sub5-sub11 elect waterb phone computer durcons)  
egen  totcons5   = rsum(food fuel edu sub1-sub11            elect waterb phone computer durcons)            /*From "totcons.do"*/

/*
If the expenditure is y, then                y  = (1+t)*x
thus the amount of tax paid is equal to      tx = t/(1+t)*y 
*/

// calculating yearly alcohol and tobacco taxes
g	fuel_tax  = ($fuel_rate/(1+$fuel_rate))  * fuel       * 12
g vat_tax   = ($vat_rate/(1+$vat_rate))    * nfood_base * 12
 
keep hid *_tax 
***************************************

sort 		hid
merge hid using `direct01', unique 
	tab  _m
	drop _m
	sort hid
merge hid using `direct02', unique 
	tab _m
	drop _m
	sort hid
merge hid using `tob_alc', unique 
	tab  _m
	drop _m
	sort hid
tempfile 	 00
save 		`00'
*******************************************

// including weights
cd\
cd\IT
use  Results\AL_Exp.dta, clear
keep hid weight

sort  hid
merge hid using `00', unique
tab   _m*
drop  _m*
*******************************************

/* some of the variables constructed above are based on the datasets that include only the subset of hh that are relevant, 
   so we can replace zero for others, e.g.: families which do not have businesses do not appear in non_farm_business_cl used above*/
mvencode    nonfarm_dir_tax alcohol_t tobacco_t,mv(0) override

// calculating total taxes
/*prior to sum, we recode the missings as zeros, as know that estimation of tax paid is an under-estimation*/
mvencode    *_tax ,mv(0) override
g       tot_dir_tax      = nonfarm_dir_tax + other_dir_tax
g       tot_indir_tax    = alcohol_tax     + tobacco_tax   + fuel_tax + vat_tax
g       tot_tax      	   = tot_indir_tax   + tot_dir_tax

keep  hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax fuel_tax  vat_tax weight
order hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax fuel_tax  vat_tax weight

sort hid
save  Results\AL_Tax.dta, replace

keep hid tot_dir_tax

************Making sure Albanian household expenditure includes total direct formal taxation
merge hid using Results\AL_Exp, sort
replace hhexp = hhexp + tot_dir_tax
drop tot_dir_tax _merge
sort hid
save Results\AL_Exp, replace
