*********************Important: MUST run after ET_Exp for accurate hhexp value*/

/*
This do file calculates the amount of formal taxes paid by hh:
	hid 			: hh identification code
	tot_tax   : total amount of tax paid
	tot_dir 	: total amount of direct tax paid
	tot_ind 	: total amount of indirect tax paid
*/

clear 
set memo 50m
set more off
cd\
cd\IT

/*All values in birr. 
	All are converted to per year*/

// defining rates of taxation
gl alc_rate  = 0.5
gl tob_rate  = 0.75
gl fuel_rate = 0.15
gl vat_rate  = 0.15             

*************************************************************************************************Direct taxes 4M(four months)**
use "OData\ET\Data\r4p1s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

//391: Code for Taxes and Levies 
keep if q16_1a == 391                
//changing to annual base
g   tot_dir_tax    =  q16_1b * 3

//dropping duplicates
duplicates drop
duplicates tag hid, gen(d)
drop if d!=0
drop d
keep hid tot_dir_tax

sort hid
tempfile tax
save `tax'
***********************************************************************************************************New Expenditure Calculations & Consumption taxes **

********************************************************************************** Tobacco 4M at 75%**
use "OData\ET\Data\r4p1s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

//430: code for cigarettes 
keep  if q16_1a == 430 		

/*
If the expenditure is y, then            y  = (1+t)*x
thus amount of tax paid is equal to      tx = t/(1+t)*y 
*/

// calculating yearly tobacco tax			
g   tobacco_tax =  q16_1b * 3 * ($tob_rate/(1+$tob_rate)) if q16_1a == 430 
g   tobacco_exp = q16_1b * 3 if q16_1a == 430

keep hid tob*
sort hid
tempfile tobacco
save    `tobacco'

**********************************************************************************Alcohol 1W at 50%**
use "OData\ET\Data\r4p3s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

// keeping alcoholic beverage consumption
keep        if (q36_1 == 71 | q36_1 == 72 | q36_1  == 73) & q36_2c != .

/*
If the expenditure is y, then            y  = (1+t)*x
thus amount of tax paid is equal to      tx = t/(1+t)*y 
*/
// calculating yearly alcohol tax
g   alcohol_tax = q36_2c * 52 * ($alc_rate/(1+$alc_rate))   /* Time period: one week */
g		alcohol_exp = q36_2c * 52

//collapsing to hh level
collapse (sum) alcohol*, by(hid)

keep 		hid alcohol_tax alcohol_exp
sort 		hid
tempfile	alcohol
save 		`alcohol'

**************************************************************************************Fuel 15%**
use "OData\ET\Data\r4p3s4f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

// keeping taxable fuel expenditure
keep if q34_1==301 
/* Using charcoal because it appears that "naphatha / diesel oil / lamba / kerosin" is exempt, or 
at least kerosene is (see IMF doc "social impact of a tax reform") */

// calculating yearly fuel tax
g		fuel_tax = q34_2 * 12 * ($fuel_rate/(1+$fuel_rate)) 			           
g		fuel_exp = q34_2 * 12

keep hid fuel_tax fuel_exp
sort hid
tempfile fuel
save `fuel'

*********************************************************************************************Household assets**(time specified each item, keeping those in previous year)**
/*Survey was conducted between June-November of 1997, the Ethiopian Calendar is 7 years, 8 months behind Gregorian Calendar
  So survey according to Ethiopian Calendar was conducted from October-March of 1989/90, want to look at an entire one year so will
  keep items bought in 1989 (1996) E.C.*/

**Not including this in expenditure calc b/c possibly production oriented

use "OData\ET\Data\r4p1s3af.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

// keeping only items purchased in entire previous calendar year
keep if q13_3 == 89
g assets_value = q13_1b * q13_2
bys hid: egen assets_exp = sum(assets_value)
keep hid assets_exp
duplicates drop

sort hid
tempfile assets
save `assets'

**********************************************************************************************House improvement/building expenditure*****Last two years**
use "OData\ET\Data\r4p1s3bf.dta", clear
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep hid q13_9w q13_9r

// correcting problematic observations
duplicates drop
drop if hid == "1010064"
replace q13_9w = . if q13_9w == 9999.99
replace q13_9r = . if q13_9r == 9999.99
drop if q13_9r == . & q13_9w == .

gen home_exp = q13_9w + q13_9r

// converting to annual base
replace home_exp = home_exp / 2
keep hid home_exp

tempfile home
save `home'

*****************************************************************************************Agricultural Input Expenditures (previous main and minor yearly season)
*Not including this in exp aggregate b/c production oriented

use "OData\ET\Data\r4p2s4f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep hid q24m_3 q24m_2 q24b_3 q24b_2 q24m_1 q24b_1
keep if q24m_2 == 1

bys hid: egen agr_input_exp1 = sum(q24m_3)
bys hid: egen agr_input_exp2 = sum(q24b_3)

egen agric_input_exp = rowtotal(agr_input*)
keep hid agric_input_exp
duplicates drop
sort hid
tempfile agriculture
save `agriculture'

**********************************************************************************************Livestock purchase (12 months)
*Not including this in exp aggregate b/c production oriented

use "OData\ET\Data\r4p2s5af.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep hid q25a_1a q25a_7a q25a_7b
duplicates drop

bys hid: egen livestock_pur_exp = sum(q25a_7b)
keep hid livestock_pur_exp
duplicates drop
sort hid
tempfile livestock_pur
save `livestock_pur'

**************************************************************************************************Livestock expenditure (last year)
*Not including this in exp aggregate b/c production oriented

use "OData\ET\Data\r4p2s6af.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep if q26_1b == 1

bys hid: egen livestock_costs_exp = sum(q26_2)
keep hid livestock_costs_exp
duplicates drop
sort hid
tempfile livestock_costs
save `livestock_costs'

*****************************************************************************************Food Expenditure**in last week*****
use "OData\ET\Data\r4p3s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

**Food purchases in last week
// dropping alcohol and tobacco (this info included elsewhere)
drop if q36_1 == 71 | q36_1 == 72 | q36_1 == 73 | q36_1 == 28

collapse (sum) q36_2c, by(hid q36_1)
drop if q36_1 == .

reshape wide q36_2c, i(hid) j(q36_1)
egen food_exp1 = rowtotal(q36_2c*)

// making yearly
replace food_exp1 = food_exp1*52
keep hid food_exp1
sort hid
tempfile food1
save `food1'

***Purchased meals outside of home + bulk cereal purchases not included in last week purchases above
use "OData\ET\Data\r4p3s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

**Lots of missings here, but not the case in previous questions from same section above, so assuming .'s are just equivalent to zeros (as zero subcategories are just not included in the food exp data above)
keep hid q36_9a-q36_12c
replace q36_9b = . if q36_9b == 999.99

***Purchased meals last week
bys hid: egen food_exp2 = sum(q36_9b)
replace food_exp2 = food_exp2 * 52

**Bulk cereals last 4 months
bys hid: egen food_exp3 = sum(q36_12c)
replace food_exp3 = food_exp3 * 3

keep hid food_exp2 food_exp3
duplicates drop

merge hid using `food1', sort
tab _m
drop _m

egen food_exp = rowtotal(food_exp*)
keep hid food_exp
tempfile food
save `food'

******************************************************************************************Non-VAT, non-food expenditure**4 months***
*Non-VAT, non-food expenditure
use "OData\ET\Data\r4p1s6f.dta", replace

g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

keep 		hid q16_1a q16_1b

// excluding expenditure subject to VAT (calculated below) and alcohol/tobacco (calculated separately elsewhere)
foreach var in 301 302 303 304 305 306 341 342 343 344 362 381 422 434 435 439 445 449 430 431 432{
	drop if q16_1a == `var'
}

collapse (sum) q16_1b, by(hid q16_1a)
drop if q16_1a == .

reshape wide q16_1b, i(hid) j(q16_1a)

egen nonvat_nonfood_exp = rowtotal(q16_1b*)

// making yearly
replace nonvat = nonvat * 3
keep hid nonvat
sort hid
tempfile nonvat
save `nonvat'

******************************************************************************Consumables*************last month****
**Excluding charcoal because that was included in the taxable fuel calculation
use "OData\ET\Data\r4p3s4f.dta", clear

g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep 		hid q34_1 q34_2

collapse (sum) q34_2, by(hid q34_1)
drop if q34_1 == . | q34_1 == 301

reshape wide q34_2, i(hid) j(q34_1)

egen consumables_exp = rowtotal(q34_23*)

// making yearly
replace consumables_exp = consumables_exp * 12
keep hid consumables
sort hid
tempfile consumables
save `consumables'

**************************************************************************************Nonfood expenditure vat-base 15%**
use "OData\ET\Data\r4p1s6f.dta", replace
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
keep 		hid q16_1a q16_1b

// separating all expenditure that can be taxed by VAT
keep 		if q16_1a < 361 | q16_1a == 362 | q16_1a == 381 | q16_1a == 422| q16_1a == 434| q16_1a == 435| q16_1a == 439| q16_1a == 445| q16_1a == 449

collapse (sum) q16_1b, by(hid q16_1a)
reshape wide q16_1b, i(hid) j(q16_1a)
qui foreach var in 301 302 303 304 305 306 341 342 343 344 362 381 422 434 435 439 445 449 {
	g q16_1b`var'_tax = q16_1b`var' * (12/4) * ($vat_rate/(1+$vat_rate))	
}

egen	vat_nonfood_exp = rowtotal(q16_1b*)

// making yearly
replace vat_nonfood_exp = vat_nonfood_exp * 3
egen    vat_tax = rowtotal(*_tax)
keep hid vat_tax vat_nonfood_exp

****************************************************************************************
foreach file in tax tobacco alcohol fuel assets home agriculture livestock_pur livestock_costs food nonvat consumables{
	merge hid using ``file'', sort _merge(_m`file')
	sort hid
	tab _m`file'
}
drop _m*

order hid *tax


egen hhexp_new = rowtotal(tobacco_exp alcohol_exp fuel_exp home_exp food_exp nonvat_nonfood_exp consumables_exp vat_nonfood_exp)
/*Many missings expected in some categories of interest (tobacco, alcohol, fuel, home) because of structure of survey, if don't have expenditure in a certain category, not included in the data, so zeros end up as missings*/


/*small number of missings for food exp, but don't want to include b/c food is major component and must be buying something*/
replace hhexp_new = . if food_exp == . | vat_nonfood_exp == .
replace hhexp_new = . if hhexp_new == 0
replace hhexp_new = hhexp_new / 12


// before summing up, recoding missings as zeros, as we know that our estimation of tax paid is an under-estimation
mvencode    *_tax ,mv(0) override

**if no VAT tax paid, then something wrong
egen    tot_indir_tax = rowtotal(vat_tax alcohol_tax tobacco_tax fuel_tax)
replace tot_indir_tax = . if vat_tax == 0

replace tot_dir_tax   = 0 if tot_dir_tax==.
g       tot_tax       = tot_dir_tax + tot_indir_tax





// dropping the observations with contradictions
sort hid
merge hid using "Results\ET_contrad.dta", unique
tab _
drop if _ ==3
drop _

tempfile temp
save `temp'

keep hid *_tax 
sort hid
save Results\ET_Tax.dta, replace

use `temp', clear
keep hid hhexp_new
merge hid using Results\ET_Exp_init.dta, sort
tab _
drop if _m == 1
drop _m

rename hhexp  cons4
rename hhexp_new  hhexp
sort hid

save Results\ET_Exp, replace

