/*
This do file calculates the amount of formal taxes paid by hh:
	hid 		: hh identification code
	tot_tax : total amount of tax paid
	tot_dir : total amount of direct tax paid
	tot_ind : total amount of indirect tax paid
*/


/* All monetary unit is PhP (Philippine Pesos)
   All are converted to per year*/

clear
set memo 50m
set more off
cd\
cd\IT

// defining rates of taxation
gl alc_rate  = 0.5
gl tob_rate  = 0.63
gl fuel_rate = 0.25
gl vat_rate  = 0.10             

*************************************************************************************** Direct taxes 6M    **
use "OData/PH/Data/hhnew.dta", replace
ren     id      hid
ren     hhwgt   weight
// determining yearly direct taxes 
g       tot_dir_tax =  2* d5b7a
/*Considering the ambiguity of d5b7b and the fact that reported only for 6 observation, exclude it*/

**************************************************************************************** Consumption taxes **

********************************************************** Tobacco 3D-63%**
/* Time period: three-day recall period, where each day is one variable */

egen    tobacco_exp  = rowtotal(d4_d*l)		     /*Sum of the 3Days*/

/*
If the expenditure is y, then            y  = (1+t)*x
thus amount of tax paid is equal to      tx = t/(1+t)*y 
*/
// calculating yearly tobacco tax
g       tobacco_tax    = tobacco_exp * ($tob_rate/(1+$tob_rate)) * (365/3)

********************************************************** Alcohol 3D-50%**
 /* Time period: three-day recall period, where each day is one variable */

// calculating yearly alcohol tax
egen    alcohol_exp  = rowtotal(d4_d*k)
g       alcohol_tax    = alcohol_exp * ($alc_rate/(1+$alc_rate)) * (365/3)

************************************************************* Fuel 1M-25%**
// calculating yearly fuel tax
g       fuel_tax       = ($fuel_rate/(1+$fuel_rate)) * (d5a1a+d5a1b) * 12     

***********************************************Nonfood expenditure 6M-10%**
/* Time period: 6 months */
/* including all expenditure taxed by VAT (clothing, recreation, non-durable furnishing, etc.)
   we include column a and b, in order to treat gift and consumed in the same manner: idea is that what hh recieved as gift play the same 
   role as the one purchased, considering the substitution between them
*/

foreach num in 1 3 5 6 8 {
	g nf`num'      = d5b`num'a + d5b`num'b
}
egen    nfood_exp    =  rowtotal(nf*)

// calculating yearly VAT tax
g       vat_tax      = ($vat_rate/(1+$vat_rate)) * 2  * nfood_exp

**************************************************************************************** Total/Result
// calculating indirect and total taxation
g 	tot_indir_tax 	=	tobacco_tax     +  alcohol_tax   +  fuel_tax + vat_tax
g 	tot_tax		=	tot_dir_tax     +  tot_indir_tax

keep  hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax fuel_tax  vat_tax weight
order hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax fuel_tax  vat_tax weight

// dropping observations with contradictions
sort hid
merge hid using "Results\PH_contrad.dta", uniqus
tab _
drop if _ ==3
drop _


save Results\PH_Tax.dta, replace
