/*
This do file calculates the amount of formal taxes paid by hh:
	hid 		: hh identification code
	tot_tax : total amount of tax paid
	tot_dir : total amount of direct tax paid
	tot_ind : total amount of indirect tax paid
*/

/* All monetary unit in thousand dong
   All values were reported per year*/


clear
set memo 50m
set more off
cd\
cd\IT

cd "OData/V02/Data/"

// defining rates of taxation
gl alc_rate  = 0.35
gl tob_rate  = 0.36
gl fuel_rate = 0.10
gl vat_rate  = 0.10             

// As the rate of taxation of fuel is the same as the VAT, we do not separate fuel from other VAT goods, calculate all together

*****Direct Taxes: using "All Kinds of Taxes" variable************************

use muc6b34.dta, replace
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
ren m6b3c2h403 tot_dir_tax

keep hid       tot_dir_tax
sort hid

order hid tot*

tempfile direct
save `direct'

*************************************************************************************Consumption taxes *

****************************************************** Tobacco & Alcohol**
use  muc6a1.dta, replace
keep tinh xa hoso madong m6a1c2b
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))

keep if madong == 155 | madong  ==  145

/*
If the expenditure is y, then            y  = (1+t)*x
thus amount of tax paid is equal to      tx = t/(1+t)*y 
*/

g tobacco1_tax    =  ($tob_rate/(1+$tob_rate)) * m6a1c2b if madong  ==  155
g alcohol1_tax    =  ($alc_rate/(1+$alc_rate))  * m6a1c2b if madong  ==  145

keep       hid tobacco1_tax alcohol1_tax

// collapsing to household level
collapse (sum) tobacco1_tax alcohol1_tax, by(hid) 

sort hid
tempfile toba_alco1
save `toba_alco1'

**************************************************
use  muc6a2.dta, replace
keep tinh xa hoso madong m6a2c6
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))

keep if madong  == 154 | madong  ==  145
g tobacco2_tax    =  ($tob_rate/(1+$tob_rate)) *  m6a2c6 if madong  ==  154
g alcohol2_tax    =  ($alc_rate/(1+$alc_rate))  *  m6a2c6 if madong  ==  145

keep       hid tobacco2_tax alcohol2_tax

// collapsing to household level
collapse (sum) tobacco2_tax alcohol2_tax, by(hid) 
sort hid
tempfile toba_alco2
save `toba_alco2'

********************************************************** Fuel/Nonfood**

/* Since these appear in the same survey - b1 - and are the same tax rate - will calculate together (fuel is codes 203, 204, 205)*/

use  muc6b1.dta, replace
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
drop if madong==999

// collapsing to household level
collapse (sum) m6b1c4, by(hid)

g nonfood1_tax  = ($vat_rate/(1+$vat_rate))  * m6b1c4

keep hid non
sort hid
tempfile nonfood1
save `nonfood1'

***********************************************
use  muc6b2.dta, replace
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
drop m6b2c3* m6b2c1* m6b2c5

egen exp          = rowtotal(m6b2c2*)
g    nonfood2_tax  = ($vat_rate/(1+$vat_rate))  * exp

keep hid non
sort hid
tempfile nonfood2
save `nonfood2'

************************************************
use  muc6b34.dta, replace
g 	hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))
keep hid m6b3c2h404 m6b3c2h405 m6b3c2h406 m6b3c2h408

egen exp          = rowtotal(m6b3c2*)
g    nonfood3_tax  = ($vat_rate/(1+$vat_rate))  * exp

keep hid non
sort hid
tempfile nonfood3
save `nonfood3'

***********************************************
use  muc7.dta, replace
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f")) 
keep if m7c3_2==2001 | m7c3_2==2002

g         durables_tax = ($vat_rate/(1+$vat_rate)) * m7c4

// collapsing to household level
collapse (sum) durables_tax, by(hid)

keep hid dur
sort hid
tempfile durables
save `durables'

************************************************ Determining weights 
use "hhexpe02"
g hid      = (string(tinh,"%03.0f") + string(xa,"%07.0f") + string(hoso,"%05.0f"))                                           

ren wt30     weight
keep 		hid weight
sort 		hid
tempfile 	weight
save 		`weight'

***************************************************************************************
foreach file in toba_alco1 toba_alco2 nonfood1 nonfood2 nonfood3 durables weight{
	merge hid using ``file'', unique _merge(_m`file')
	tab _m`file'
	sort hid
}
drop _m*

**************************************************************************************
// before summing up, we recode missings as zeros, as we know that our estimation of tax paid is an under-estimation
mvencode    *_tax ,mv(0) override

// calculating indirect and total taxation  
g		tobacco_tax       = 	tobacco1_tax    +	 tobacco2_tax
g		alcohol_tax       = 	alcohol1_tax    +  alcohol2_tax
g   vat_tax           =   durables_tax    +  nonfood1_tax   + nonfood2_tax    +  nonfood3_tax
g 	tot_indir_tax 		=	tobacco_tax       +  alcohol_tax  	+ vat_tax

sort hid 
merge hid using `direct', unique
tab _
drop _
mvencode    *_tax ,mv(0) override
g tot_tax = tot_dir_tax + tot_indir_tax

keep  hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax vat_tax weight
order hid tot_tax tot_dir tot_ind alcohol_tax tobacco_tax vat_tax weight

// dropping observations with contradictions
sort hid
cd\
cd\IT
merge hid using "Results\V02_contrad.dta", uniqus
tab _
drop if _ ==3
drop _

save Results\V02_Tax.dta, replace 
