/*
This do file constructs a prediction for wage of each individual, based on characteristics collected/calculated 
by "wage predictor ingeredients" do file.  Important only for countries on which have info for intensive margin.
*/

clear
set memo 50m
set more off
cap log close
cd\
cd\IT\Results


*****************************************************************************************************************************************
//List of countries for which will repeat the same process using individual level data
gl country_list        AL ID07 PH V02

// The main loop to be repeated for each country
foreach cty in $country_list {	
	use "`cty'_ind_data.dta", replace

	disp "********************************* `cty'*****************************************" 	

	//predicting the wage only for workers
	keep if workerind ==1
	
	// defining a log of hh expenditure per worker
	g logexp_worker = log(hhexp/worker)
	
	ren gender_d gender
	
	/*separating the datasets with urban and rural households from ones with only rural households, as we want to use urban information
	  in the regression to predict individual wages*/
	
	capture confirm variable urban
		if !_rc {
			// creating interaction dummies
			g urban_gender = urban* gender
			foreach var1 in gender urban urban_gender{
				foreach var2 in age age_sq education{
					g `var1'_`var2'=`var1'*`var2'
				}
	    }
			//regressing the log of exp per worker on the individual characteristics and province dummy
			quie areg logexp_worker  age age_sq education gender urban gender_age gender_age_sq gender_education urban_age urban_age_sq urban_education urban_gender urban_gender_age urban_gender_age_sq urban_gender_education [pw = weight], absorb(province) r
		}
		else{
			foreach var1 in gender{
				foreach var2 in age age_sq education{
					g `var1'_`var2'=`var1'*`var2'
				}
			}
 			quie areg logexp_worker age age_sq education gender gender_age gender_age_sq gender_education [pw = weight] , absorb(province) r
		}
	predict logwage_hat
	g wage_hat = exp(logwage_hat)
	
	// at hh level, calculating predicted wage average over # of worker in the HH and minimum predicted wage
	collapse (mean) HHwage_Av_hat=wage_hat (min) HHwage_min_hat=wage_hat, by(hid)  
	save "`cty'_ind_wage_predicted.dta", replace	
}


********************************************************************************************
/*for Ethiopia, education has too many missing values. So will use same methodology as above, but also adding dummy for 
  individual whose education data is missing*/

use "ET_ind_data.dta", replace

disp "********************************* Ethiopia*****************************************" 	
	
keep if workerind ==1
ren gender_d gender
	
g logexp_worker = log(hhexp/worker)
g edu_miss_d  = education==.
g edu_wo_miss = education if education != .
	
replace edu_wo_miss = 0   if education == .
foreach var1 in gender{
	foreach var2 in age age_sq edu_wo_miss edu_miss_d{
		g `var1'_`var2'=`var1'*`var2'
	}
}
		
quie areg logexp_worker age age_sq edu_wo_miss edu_miss_d gender gender_age gender_age_sq gender_edu_wo_miss gender_edu_miss_d [pw = weight], absorb(province) r
predict logwage_hat
g wage_hat = exp(logwage_hat)
	
collapse (mean) HHwage_Av_hat=wage_hat (min) HHwage_min_hat=wage_hat,by(hid)
save "ET_ind_wage_predicted.dta", replace			

cd\
cd\IT
