/* "Table 4: Informal Taxation, Expenditure, and Formal Taxation"
   "Table 5: Comparison to other local budgets in Indonesia" */
   
clear
cap log close
cd\

set memo 700m
set more off
do "IT\DoFiles Public\0. AdoFiles\fanreg.ado" 
cd\IT\Results

// parameters chosen to calculate the Equivalent to Scale (ES) households size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85


********Table 4

// list of countries considered for this analysis
gl country_list PH AL ET ID07 V02

local first = 1

foreach cty in $country_list {	

	// importing and generating necessary variables
	use "`cty'_Tax.dta", clear
	sort hid
	merge hid using "`cty'_Exp.dta", unique
	tab   _
	drop  _
	merge hid using "`cty'_ind_wage_predicted.dta", sort
	tab _
	drop _

	// ratio of direct tax over expenditure
	g r_tot_dir_tax 	=   (tot_dir_tax/(12*hhexp))

	// ratio of indirect tax over expenditure
	g r_tot_indir_tax =   (tot_indir_tax/(12*hhexp))

	// ratio of total formal tax over expenditure
	g r_tot_tax 				= (tot_tax/(12*hhexp))
	g	r_lab_infor_days  = (days/(250*worker))

	drop if r_lab_infor_days > .5 & r_lab_infor_days < .

	// 21.7 work days a month (30.4375*5/7); labor monetization: (total days in a year contributed by HH) * (monthly avg. HH wage/possible work days per month)
	// ratio of monetized labor part of contribution over expenditure
	g lab_infor_tax 	= ((days*HHwage_Av_hat)/ 21.7)
	g r_lab_infor_tax = (lab_infor_tax / (12*hhexp))

	drop if r_lab_infor_tax > .5 & r_lab_infor_tax < .

	
	// drop 2 remaining problematic obs (assuming misentry) 
	if "`cty'" == "V02"{
		drop if r_tot_dir_tax > 1 & r_tot_dir_tax < .
	}
	
	/*Now have same obs as in `cty'_keeplist.dta*/

	capture confirm variable dollars
   if !_rc {
		// ratio of monetary part of contribution over expenditure
		g mon_infor_tax		=  dollars
		g r_mon_infor_tax =  (dollars/(12*hhexp))

		// ratio of total informal contribution over expenditure
 		g r_infor_tax 		= r_lab_infor_tax + r_mon_infor_tax
		g infor_tax 			= lab_infor_tax + mon_infor_tax
	}
	else{
		// ratio of total informal contribution over expenditure (if only labor info available)
 		g r_infor_tax			= r_lab_infor_tax
		g infor_tax 			= lab_infor_tax
	}

	// ratio of informal tax over total of informal + formal tax
	g tot_all_tax = tot_tax + infor_tax
	g r_inf_over_all_tax = (infor_tax / tot_all_tax)


	tempfile `cty'_taxvals
	save ``cty'_taxvals'

	
  gen country = "`cty'" in 1
	gen str ratio = ""
	gen mean = .
	gen obs = .

	********
	// country level averages
		
	// "Informal tax as a share of HH expenditure"

		// "All households" 
		summ r_infor_tax [w=weight], d 
		replace ratio = "r_infor_tax" in 2
		replace mean = r(mean) in 2
		replace obs = r(N) in 2
		
		// "Conditional on informal tax > 0"
		summ r_infor_tax if infor_tax > 0 [w=weight], d 
		replace ratio = "cond_r_infor_tax" in 3
		replace mean = r(mean) in 3
		replace obs = r(N) in 3

	// "Informal tax as a share of HH Total Formal + Informal Tax payments"

		// "All households"
		summ r_inf_over_all_tax [w=weight], d
		replace ratio = "r_inf_over_all_tax" in 5
		replace mean = r(mean) in 5
		replace obs = r(N) in 5

		// "Conditional on informal tax > 0"
		summ r_inf_over_all_tax if infor_tax > 0 [w=weight] , d
		replace ratio = "cond_r_inf_over_all_tax" in 6
		replace mean = r(mean) in 6
		replace obs = r(N) in 6

	********

	// combining all countries' results info into single table
	if "`first'" == "1"{
		outsheet country ratio mean obs using table4_dropobs in 1/6, replace
	}
	else{
		outsheet country ratio mean obs using table4_`cty'_dropobs in 1/6, replace			
		appendfile table4_`cty'_dropobs.out table4_dropobs.out
	}
	
	local first = 0	

	save table4_`cty'_dropobs, replace

}


********Table 5

** "From district budget data:"

cd\
cd\IT

use OData\ID07\budget2007,clear

keep daerah pendapatan var31 bagianpendapatanaslidaerah danaperimbangan belanja belanjapegawai belanjabarangdanjasa belanjamodal lainlainpendapatandaerahyangsah

g kabid = ""
replace kabid = "3202" if daerah == "Kab. Sukabumi"
replace kabid = "3208" if daerah == "Kab. Kuningan"
replace kabid = "3210" if daerah == "Kab. Majalengka"
replace kabid = "3211" if daerah == "Kab. Sumedang"
replace kabid = "3213" if daerah == "Kab. Subang"
replace kabid = "3503" if daerah == "Kab. Trenggalek"
replace kabid = "3507" if daerah == "Kab. Malang"
replace kabid = "3518" if daerah == "Kab. Nganjuk"
replace kabid = "3520" if daerah == "Kab. Magetan"
replace kabid = "3528" if daerah == "Kab. Pamekasan"
replace kabid = "5302" if daerah == "Kab. Sumba Timur"
replace kabid = "5305" if daerah == "Kab. Timor Tengah Utara"
replace kabid = "5308" if daerah == "Kab. Lembata"
replace kabid = "5309" if daerah == "Kab. Flores Timur"
replace kabid = "5314" if daerah == "Kab. Rote Ndao"
replace kabid = "7106" if daerah == "Kab. Minahasa Utara"
replace kabid = "7501" if daerah == "Kab. Boalemo"
replace kabid = "7502" if daerah == "Kab. Gorontalo"
replace kabid = "7503" if daerah == "Kab. Pohuwato"

// keeping 19 kabupaten for which have complete data from household survey, village budget data, and district budget data
keep if kabid != ""

sort kabid
tempfile temp1
save `temp1'

use OData\ID07\pds2008_a.dta,clear

g kabid = prop + kab

g numhh = r401c
collapse (sum) numhh, by(kabid)

keep kabid numhh

sort kabid
merge kabid using `temp1', unique
tab _merge
keep if _merge == 3

ren var31 belanjapegawai2

for var bagianpendapatanaslidaerah danaperimbangan belanja belanjapegawai belanjabarangdanjasa belanjamodal lainlainpendapatandaerahyangsah: replace X = subinstr(X,".","",.) \ destring X,replace force

// total district expenditures
g float kabexp = belanja / numhh * 1000000
g kabexp_PPP = kabexp / 3571

// expenditures on salaries
g float kabexp_worker = (belanjapegawai + belanjapegawai2) / numhh * 1000000
g kabexp_worker_PPP = kabexp_worker / 3571

// expenditures on goods & services
g float kabexp_goodsservice = (belanjabarangdanjasa ) / numhh * 1000000
g kabexp_goodsservice_PPP = kabexp_goodsservice/ 3571

// expenditures on capital investments
g float kabexp_capital = (belanjamodal) / numhh * 1000000
g kabexp_capital_PPP = kabexp_capital / 3571


// district revenue from inter-governmental transfers and other sources
g float kabincome_intergov = danaperimbangan / numhh * 1000000
g kabincome_intergov_PPP = kabincome_intergov / 3571

// district revenue from local formal taxes/fees
g float kabincome_own = bagianpendapatanaslidaerah / numhh * 1000000
g kabincome_own_PPP = kabincome_own / 3571

// district revenue from other sources
g float kabincome_other = lainlainpendapatandaerahyangsah / numhh * 1000000
g kabincome_other_PPP = kabincome_other / 3571


summ *PPP
gen title = ""
gen mean = .

replace title = "Total district expenditures" in 1
summ kabexp_PPP, d
replace mean = r(mean) in 1

replace title = "Expenditures on salaries" in 2
summ kabexp_worker_PPP, d
replace mean = r(mean) in 2

replace title = "Expenditures on goods & services" in 3
summ kabexp_goodsservice_PPP, d
replace mean = r(mean) in 3

replace title = "Expenditures on capital investments" in 4
summ kabexp_capital_PPP, d
replace mean = r(mean) in 4

replace title = "District revenue from inter-governmental transfers and other sources" in 6
summ kabincome_intergov_PPP, d
replace mean = r(mean) in 6

replace title = "District revenue from local formal taxes/fees" in 7
summ kabincome_own_PPP, d
replace mean = r(mean) in 7

replace title = "District revenue from other sources" in 8
summ kabincome_other_PPP, d
replace mean = r(mean) in 8

outsheet title mean using Results\table5_district.out, replace