/* "Table 7: Formal taxes vs. household expenditure: quantities" */

clear
cap clear matrix
cap log close
cd\

set memo 50m
set more off
cd\IT
do "DoFiles Public\0. AdoFiles\maketable5.ado"  
cd\IT\Results

**********************************************************************
// country name variables
gl   AL_country  = "Albania"
gl   ET_country  = "Ethiopia"
gl   GU_country  = "Guatemala"
gl ID07_country  = "Indonesia 2007"
gl NG04_country  = "Nigeria 2004"
gl   NI_country  = "Nicaragua"
gl   PA_country  = "Panama"
gl   PH_country  = "Philippines"
gl  V02_country  = "Vietnam 2002"
gl   ZA_country  = "Zambia"

// contribution variables
gl AL_LHS 				labor
gl ET_LHS 				labor
gl GU_LHS 				labor
gl ID07_LHS 	any labor money
gl NG04_LHS 			labor
gl NI_LHS 		any labor money
gl PA_LHS  		any labor money
gl PH_LHS 				labor     
gl V02_LHS 		any labor money 
gl ZA_LHS 		any labor money

// parameters chosen to calculate the Equivalent to Scale (ES) households size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

gl country_list PH AL ET ID07 V02 

// choosing expenditure variable on which will regress contributions
gl regressors logESexp   					

// choosing variable to indicate will keep coeff to export
gl coeff_kept logESexp   	    		

***************************************************** Panel A: Informal Taxes (with FE)
gl N=0

foreach cty in $country_list{	
	// loading data (already excluding implausible obs)	
	use "`cty'_ind_wage_predicted.dta", replace
	disp "****`cty'****"
  sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1

	// calculating predicted monetary value of the labor contribution of each household
	g labor_quan = (HHwage_Av_hat/21.7) * days

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

  // defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_uncond = .
	
	// fixed-effects poisson (Quasi-ML) regression with robust standard errors for monetized labor contribution	  
	quie xtpqml labor_quan $regressors, i(cluster) cluster(cluster)  
	if $N==0{
		maketable5 using table7_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) replace
		replace obs_count_uncond = e(N) in 1	
		outsheet obs_country obs_count_uncond using table7_panelA_dropobs_obscount in 1, replace	
	}
	else{
		maketable5 using table7_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) append
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelA_dropobs_obscount_`cty' in 1, replace
	}

	// if have value of monetary contribution, repeat above for monetary contributions and sum of both
	capture confirm variable dollars
  if !_rc{
		g tot_cont = labor_quan + dollars
		quie xtpqml dollars $regressors, i(cluster) cluster(cluster)  
		maketable5 using table7_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(money) append		
		quie xtpqml tot_cont  $regressors, i(cluster) cluster(cluster)
		maketable5 using table7_panelA_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(any) append  
		
		// for those with just labor use that for total, for those with both contribution types use total combined contribution
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelA_dropobs_obscount_`cty' in 1, replace
		appendfile table7_panelA_dropobs_obscount_`cty'.out table7_panelA_dropobs_obscount.out
	}
	else{
		if $N==1{
			appendfile table7_panelA_dropobs_obscount_`cty'.out table7_panelA_dropobs_obscount.out
		}
	}	
	gl N=1
}



***************************************************** Panel B: Direct Formal Taxes (with FE)
gl N=0

foreach cty in $country_list {	
	// loading data (already excluding implausible obs)
	use "`cty'_ind_wage_predicted.dta", replace
	disp "**** `cty' ****"
	sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1
	if "`cty'" == "ID07" | "`cty'" == "PH" | "`cty'" == "AL" | "`cty'" == "ET" |"`cty'" == "V02"{
		merge hid using "`cty'_Tax.dta", sort _merge(_m2)
	}

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

	// defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_uncond = .

	// fixed-effects poisson (Quasi-ML) regression with robust standard errors for direct formal taxes	  
	xtpqml tot_dir_tax $regressors, i(cluster) cluster(cluster)  
	if $N==0{
		maketable5 using table7_panelB_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) replace
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelB_dropobs_obscount in 1, replace	
		gl N=1
	}
	else{
		maketable5 using table7_panelB_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) append
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelB_dropobs_obscount_`cty' in 1, replace
		appendfile table7_panelB_dropobs_obscount_`cty'.out table7_panelB_dropobs_obscount.out
	}	
}

***************************************************** Panel C: Informal Taxes (w/o FE)
gl N = 0

foreach cty in $country_list{
	// loading data (already excluding implausible obs)		
	use "`cty'_ind_wage_predicted.dta", replace
	disp "****`cty'****"
	sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1

	// calculating predicted monetary value of the labor contribution of each household
	g labor_quan = (HHwage_Av_hat/21.7) * days

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

  // defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_uncond = .

	// poisson regression with robust standard errors for monetized labor contribution	  
	quie poisson labor_quan $regressors , robust cluster(cluster)     
	if $N==0{
		maketable5 using table7_panelC_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) replace
		replace obs_count_uncond = e(N) in 1	
		outsheet obs_country obs_count_uncond using table7_panelC_dropobs_obscount in 1, replace	
	}
	else{
		maketable5 using table7_panelC_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) append
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelC_dropobs_obscount_`cty' in 1, replace
	}
		
	// if have value of monetary contribution, repeat above for monetary contributions and sum of both
	capture confirm variable dollars
	if !_rc {
		g tot_cont = labor_quan + dollars
		quie poisson dollars  $regressors, robust cluster(cluster)     
		maketable5 using table7_panelC_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(money) append
		quie poisson tot_cont $regressors, robust cluster(cluster)     
		maketable5 using table7_panelC_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(any) append
	
		// for those with just labor use that for total, for those with both contribution types use total combined contribution
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelC_dropobs_obscount_`cty' in 1, replace
		appendfile table7_panelC_dropobs_obscount_`cty'.out table7_panelC_dropobs_obscount.out
		}
	else{
		if $N==1{
			appendfile table7_panelC_dropobs_obscount_`cty'.out table7_panelC_dropobs_obscount.out
		}
	}		
	gl N=1
}


***************************************************** Panel D: Direct Formal Taxes (w/o FE)
gl N=0

foreach cty in $country_list {	
	// loading data (already excluding implausible obs)
	use "`cty'_ind_wage_predicted.dta", replace
	disp "****`cty'****"
	sort hid
	merge hid using "`cty'_keeplist.dta", sort
	keep if _m != 1
	if "`cty'" == "ID07" | "`cty'" == "PH" | "`cty'" == "AL" | "`cty'" == "ET" |"`cty'" == "V02"{
		merge hid using "`cty'_Tax.dta", sort _merge(_m2)
	}

	// defining expenditure variable
	g logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
		
	// defining variable to store obs count
	g obs_country = "`cty'" in 1
	g obs_count_uncond = .

	// poisson regression with robust standard errors for direct formal taxes	  
	poisson tot_dir_tax $regressors, robust cluster(cluster)     
	if $N==0{
		maketable5 using table7_panelD_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) replace
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelD_dropobs_obscount in 1, replace	
		gl N=1
	}
	else{
		maketable5 using table7_panelD_dropobs, rhs($coeff_kept) varcol($`cty'_country) varrow(labor) append
		replace obs_count_uncond = e(N) in 1
		outsheet obs_country obs_count_uncond using table7_panelD_dropobs_obscount_`cty' in 1, replace
		appendfile table7_panelD_dropobs_obscount_`cty'.out table7_panelD_dropobs_obscount.out
	}
}



cd\
cd\IT


