/*"Table 9: User Fees"*/


****************************************************Indonesia 2007	
******************************************************************


clear
cap clear matrix
cd\
cd IT
set memo 400m
set more off
cd "OData\ID07\Data3\"


*****Contribution to School/Water
use R.dta, clear

// generating cluster variable
g cc = string(rlk01_cd,"%02.0f") + string(rlk02_cd,"%02.0f") +string(rlk03_cd,"%03.0f") +string(rlk04_cd,"%03.0f")
destring cc, generate(cluster) ignore(".")
format cluster %15.0f

// renaming the household id for consistency with other datasets
ren rid hid

// question PM11 has multiple answers, creating variable for each
multparse rpm11 cont

***already have the proper missings coming from rpm10 == 3 included
// renaming variables created by multparse from rpm11
rename cont_B cont_school
rename cont_C cont_water

drop cont_A cont_D cont_E cont_F cont_G cont_H cont_V cont_Z 

**If rpm10 answered as "No" (have there been community activities in this village) then rpm10a (has HH participated) missing
**If rpm10 answered "Yes" then rpm10a either yes or no (no missings), if rpm10a answered as "no" then all contribution types missing
**Correct these missings which should be zeros below
foreach Z in school water{
	replace cont_`Z' = 0 if rpm10 == 3 | rpm10a == 3
}

**All remaining missings for each cont_* variable of interest due to rpm10 being answered "No", i.e no community activities going on



*****Water Usage

g 			water_usage1 = 1 if rkr04 == 1
replace	water_usage1 = 0 if rkr04 != 1
replace	water_usage1 = 1 if ((rkr04 == 2 | rkr04 == 3) & rkr05 == 3)
replace	water_usage1 = . if rkr04 == 95 	

replace   water_usage1 = . if rkr04==.

keep hid cont_* *usage* cluster 
sort hid
aorder

duplicates drop hid, force
tempfile 01
save    `01'

*****School Usage

use R_AR_01, clear
ren rid hid

g age = 2007 - rar04_yy
keep hid age rar09

g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

collapse (sum)hhadults=adults (sum)hhkids=kids (sum)hhbabies=babies, by(hid)

sort  hid
tempfile student 
save    `student'

****************************
// merging datasets
sort hid 
merge hid using `01', unique
tab _m 
drop _
aorder

cd\
cd IT
sort hid
merge hid using "Results\ID07_Exp", unique
tab _
drop _

// dropping implausible obs, as have throughout
sort hid
merge hid using "Results\ID07_keeplist_ids", unique
tab _m
keep if _m == 3
drop _m

***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0

keep cont* *usage* logESexp cluster weight hid *_d weiclus labor money any


// creating variables which allow retention in regressions of obs which missing water usage info
gen miss_water_d = water_usage1 == .
gen waterusage_wo_miss = water_usage1
replace waterusage_wo_miss = 0 if waterusage_wo_miss == .
rename water_usage1 full_wateruse


// contribution/usage regressions
foreach Z in cont_schoo cont_water{
	clogit `Z' HHkids_d waterusage miss_water logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_schoo"{
		outreg2 using "Results\table9_regs_ID07", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_ID07", excel
	}

	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_ID07", excel
}








****************************************************Nicaragua	
*************************************************************

cd\
cd IT

use "OData\NI\Data\VIVIEND.DTA", clear
ren  i00   hid

// correcting for multi answer questions
foreach num in 1 3 7{                  
	tostring vb570`num', gen(vb570`num'_s)
	g vb570`num'_1 = substr(vb570`num'_s, 1, 1)   
	g vb570`num'_2 = substr(vb570`num'_s, 2, 2) if vb570`num' !=. 
	replace vb570`num'_2 = "."                  if vb570`num' ==. | vb570`num'_2 =="0" 
}

*****Contribution to school/water
 
**people who not benefit are categorized as non-contributer (by survey designer), provides a lower bound
g cont_school = 0 
replace cont_school = . if missing(vb5501)
g	cont_water = 0
replace cont_water  = . if missing(vb5503)

foreach ii in 1 2{
	replace cont_school = 1 if vb5701_`ii' == "1" |  vb5701_`ii' == "2" | vb5701_`ii' == "3" | vb5701_`ii' == "4" | vb5701_`ii' == "5"
}
foreach ii in 1 2{
	replace cont_water = 1 	if vb5703_`ii' == "1" | vb5703_`ii' == "3" 
	replace cont_water = 1 	if vb5703_`ii' == "2" | vb5703_`ii' == "4" | vb5703_`ii' == "5"
}


*****Water Usage

gen water_usage1 = 0
replace water_usage1 = 1 if vb18 == 1| vb18 == 2| vb18 == 3
replace water_usage1 = . if vb18 == 8 | vb18 == 4
**public/private well coded as missing because can't distinguish exactly between two categories desired	

keep hid cont_* water* i01 i02
sort hid
tempfile 01
save `01'

***********************************************************************
// merging datasets
use Results\NI_Exp.dta, clear           
sort hid
merge hid using `01', unique
tab _
drop _

// dropping implausible obs, as have throughout
sort hid
merge hid using "Results\NI_keeplist_ids", unique
tab _m
keep if _m == 3
drop _m


keep  cluster hid hhsize weight urban cont* water* hh* weiclus labor any
order cluster hid hhsize weight urban cont* water* hh*



***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0


// creating variables which allow retention in regressions of obs which missing water usage info
gen miss_water_d = water_usage1 == .
gen waterusage_wo_miss = water_usage1
replace waterusage_wo_miss = 0 if waterusage_wo_miss == .
rename water_usage1 full_wateruse

// updating contribution values to 0 if no household in cluster is contributing
bys cluster: egen school_able = max(cont_school)
bys cluster: egen water_able = max(cont_water)
replace cont_school = 0 if school_able == 0
replace cont_water = 0 if water_able == 0

// contribution/usage regressions
foreach Z in cont_schoo cont_water{
	clogit `Z' HHkids_d waterusage miss_water logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_schoo"{
		outreg2 using "Results\table9_regs_NI", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_NI", excel
	}	
	
	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_NI", excel
}





****************************************************Nigeria 2004	
****************************************************************
cd\
cd IT
do "DoFiles Public\0. AdoFiles\realtable.ado"  
cd "OData\NG04"

*****School contribution
use "social capital and community participation.dta", clear
g hid = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")
keep compropa comprog hid

**option two of the contribution question is about the school construction
g cont_school = 0
replace cont_school = 1 if compropa == 2

sort hid
tempfile 01
save `01'

use "total household expenditure.dta"
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")
keep hid ric state pid sector weightea popwt  fdtot nfdtot fdtotpr hhexp
replace      hhexp   = hhexp/12 				

sort hid
merge hid using `01', uniqus
tab _
drop _

// gathering urban and hh weight info
ren sector urban
recode urban (2 = 0)
g cluster = string(state,"%02.0f") +string(ric,"%04.0f") +string(urban,"%01.0f")

ren weightea weight 													  

sort hid
tempfile 02
save `02'

*******************************************************
cd\
cd IT
use "OData\NG04\household roaster for each person.dta",clear
g   hid   = string(state,"%02.0f") +string(ric,"%04.0f") +string(hhno,"%03.0f")

ren ageyear age
keep hid age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating at household level
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
                   
sort hid
merge hid using `02', unique
tab _
drop _
sort hid

// dropping implausible obs, as have throughout
merge hid using "Results\NG04_keeplist", sort
tab _

sort hid
gen any = labor

keep  cluster hid hhsize weight urban cont_school hh* weiclus any
order cluster hid hhsize weight urban cont_school hh* 


***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0

// updating contribution values to 0 if no household in cluster is contributing
bys cluster: egen school_able = max(cont_school)
replace cont_school = 0 if school_able == 0

// contribution/usage regressions
foreach Z in cont_school{
	clogit `Z' HHkids_d logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_school"{
		outreg2 using "Results\table9_regs_NG04", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_NG04", excel
	}	

	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_NG04", excel
}





****************************************************Panama	
**********************************************************
cd\
cd IT

use "OData\PA\Data\E03CS02.dta", clear
ren  form hid


*****School/water contribution

**if not benefit, then not contribute (as with Nicaragua), will use whether anyone contributed in community to determine if possibility to do so existed
g cont_school = 0
g cont_water = 0

foreach num in 1 2 3{
		replace cont_school = 1 if csb13a`num' == 2 | csb13a`num' == 3 | csb13a`num' == 1 | csb13a`num' == 4 | csb13a`num' == 6 | csb13a`num'== 5
		replace cont_water = 1 if csb13c`num' == 2 | csb13c`num' == 3 | csb13c`num' == 1 | csb13c`num' == 4 | csb13c`num' == 6 | csb13c`num'== 5
}

sort hid
keep hid cont_*
tempfile 01
save `01'

*****Water usage

use "OData\PA\Data\E03HG01.dta", clear
ren form hid
gen water_usage1 = 0
replace water_usage1 = 1 if v19 == 1 | v19 == 2
replace water_usage1 = . if v19 == 7 | v19 == 4 | v19 == 5

sort hid
keep hid water*

// merging datasets
merge hid using "Results\PA_Exp.dta", sort
tab  _
drop _

merge hid using `01', sort
tab _
drop _

// dropping implausible obs, as have throughout
sort hid
merge hid using "Results\PA_keeplist_ids", unique
tab _m
keep if _m == 3
drop _m

***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0


// creating variables which allow retention in regressions of obs which missing water usage info
gen miss_water_d = water_usage1 == .
gen waterusage_wo_miss = water_usage1
replace waterusage_wo_miss = 0 if waterusage_wo_miss == .
rename water_usage1 full_wateruse

// updating contribution values to 0 if no household in cluster is contributing
bys cluster: egen school_able = max(cont_school)
bys cluster: egen water_able = max(cont_water)
replace cont_school = 0 if school_able == 0
replace cont_water = 0 if water_able == 0

// contribution/usage regressions
foreach Z in cont_schoo cont_water{
	clogit `Z' HHkids_d waterusage miss_water logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_schoo"{
		outreg2 using "Results\table9_regs_PA", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_PA", excel
	}	

	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_PA", excel
}





****************************************************Zambia	
**********************************************************
cd\
cd IT

use "OData\ZA\data\SECT13.dta", clear

duplicates drop
duplicates tag hid, gen(d)
tab d
drop if d!=0

/*this part added to take care of the conditionality of s13`nn'q8 on s13`nn'q3*/
foreach nn of numlist 1/12 14 {
	replace s13`nn'q8 = 0 if s13`nn'q3 == 2 | s13`nn'q3 == 3
}             

keep hid s13*q8 s13*q3
drop s1313q8 s1315q8-s1324q8 s1313q3 s1315q3-s1324q3

*****Water/school contribution
// creating contribution and occurence variables 
** e.g. occu_school: school project occured
**      cont_school: contribute to school project	

gen cont_school   = 0
gen occu_school   = 0

gen cont_water	= 0
gen occu_water	= 0

foreach mm of numlist 1 2 3 4 5 {		
	replace cont_school=1 if s131q8==`mm' | s132q8==`mm'
	replace occu_school=1 if s131q3==1    | s132q3==1
	**This doesn't change anything after reconfiguring 0/missings from earlier version, leave in for clarification of how handling things
	replace occu_school=0 if s131q3==3 & s132q3 == 3
	}

***Any of well, borehole, piped plus "Water supply rehabilitated or improved?"
foreach mm of numlist 1 2 3 4 5 {		
	replace cont_water   =1 if s138q8==`mm' | s139q8==`mm' | s1310q8== `mm' | s1311q8== `mm'
	replace occu_water   =1 if s138q3==1 | s139q3==1 | s1310q3==1 | s1311q3==1
}

keep hid cont_* occu_*			     
sort hid
merge hid using Results\ZA_Exp, unique
tab  _
drop _
sort hid
tempfile 01
save `01'


**if one person in the cluster(village) claims occurence of a project, assume others forgot to mention it
collapse (max) occu_*, by(cluster)
sort cluster
tempfile 010
save `010'

use `01', clear
drop occu*
sort cluster

merge cluster using `010', uniqus
tab _
drop _

foreach X in school water{
	replace cont_`X' = 0 if occu_`X' == 0
}

sort hid
tempfile 02
save `02'

******Water usage
use "OData\ZA\data\SECT8.dta", clear
duplicates drop hid, force

// creating dummy for main source of hh water supply 
**This measure is slightly different than sum of well, borehole, and piped b/c not including unprotected well to keep consistent with construction of variable in other countries
g water_usage1 = s8q4a==4 | s8q4b==4 | s8q4a==5 | s8q4a==6 | s8q4a==7 | s8q4b==5 | s8q4b ==6 | s8q4b==7
replace water_usage1 = . if (s8q4a == 8 | s8q4a == 2 | s8q4a == 3) & (s8q4b == 8 | s8q4b == 2 | s8q4b == 3)

keep hid water
sort hid
tempfile 03
save `03'


sort hid
merge hid using `02', unique
tab _
drop _

// dropping implausible obs, as have throughout
merge hid using "Results\ZA_keeplist", sort
tab _
keep if _ == 3
drop _

*********************************************************************
keep  cluster hid hhsize weight urban any* labor* money* hh* cont* occ* water weiclus 
order cluster hid hhsize weight urban any* labor* money* hh*


***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0

// creating variables which allow retention in regressions of obs which missing water usage info
gen miss_water_d = water_usage1 == .
gen waterusage_wo_miss = water_usage1
replace waterusage_wo_miss = 0 if waterusage_wo_miss == .
rename water_usage1 full_wateruse

// contribution/usage regressions
foreach Z in cont_school cont_water{
	clogit `Z' HHkids_d waterusage miss_water logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_school"{
		outreg2 using "Results\table9_regs_ZA", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_ZA", excel
	}	

	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_ZA", excel
}




****************************************************Philippines	
**********************************************************
cd\
cd IT

use "OData\PH\Data\hhnew.dta", clear

ren id hid
ren hhwgt weight
ren barangay cluster

*****School/water contribution
/*question e1ai has three options to indicate the three activities that household contributed to, choose ones that are relevant*/
recode  e1ai_* (98=.) (888=.)                                          

gen cont_water = 0
**pump ambiguous water v irrig, so not including in those categories
gen cont_school = 0

qui foreach var in 1 2 3{
	foreach num of numlist 81 151{
		replace cont_water = 1 if e1ai_`var' == `num'
	}
	foreach num of numlist 22 26 45 53 76 77 111 160{
		replace cont_school = 1 if e1ai_`var' == `num'
	}
}


*****Water usage
gen water_usage1 = 0
replace water_usage1 = 1 if c3a == 1 | c3a == 3 | c3a == 4


************
keep hid cont_* *usage* cluster
sort hid
aorder
duplicates drop hid, force

merge hid using "Results\PH_Exp.dta", sort
tab  _
drop _

// dropping implausible obs, as have throughout
sort hid
merge hid using "Results\PH_keeplist_ids", unique
tab _m
keep if _m == 3
drop _m




***********************
// parameters chosen to calculate the Equivalent to Scale (ES) household size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85

// generating expenditure variable and dummy for whether kids present in household
g logESexp = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))
g HHkids_d = hhkids>0

// creating variables which allow retention in regressions of obs which missing water usage info
gen miss_water_d = water_usage1 == .
gen waterusage_wo_miss = water_usage1
replace waterusage_wo_miss = 0 if waterusage_wo_miss == .
rename water_usage1 full_wateruse
**No missing in water, so dummy will drop out

// contribution/usage regressions
foreach Z in cont_school cont_water{
	clogit `Z' HHkids_d waterusage miss_water logESexp [pw=weiclus], group(cluster) cluster(cluster)
	if "`Z'" == "cont_school"{
		outreg2 using "Results\table9_regs_PH", replace excel
	}
	else{
		outreg2 using "Results\table9_regs_PH", excel
	}	
	
	clogit `Z' logESexp [pw=weiclus], group(cluster) cluster(cluster)
	outreg2 using "Results\table9_regs_PH", excel
}


